aboutsummaryrefslogtreecommitdiff
path: root/classes
diff options
context:
space:
mode:
authorSilvio <silvio@devlet.com.br>2010-07-23 14:11:20 -0300
committerSilvio <silvio@devlet.com.br>2010-07-23 14:11:20 -0300
commitc33739f87ebf10e494f3c4d16ef4d53876f044f2 (patch)
treeb9118be218bf8e971933c7235a675afacd56e1e2 /classes
parent746f86a86cb03527ba1d4e695314d7654ecd0766 (diff)
downloadcinisis-c33739f87ebf10e494f3c4d16ef4d53876f044f2.tar.gz
cinisis-c33739f87ebf10e494f3c4d16ef4d53876f044f2.tar.bz2
Adding README and naming changes
Diffstat (limited to 'classes')
-rw-r--r--classes/BiblioIsisDb.php6
-rw-r--r--classes/IsisConnector.php12
-rw-r--r--classes/IsisDb.php8
-rw-r--r--classes/MaleteDb.php6
-rw-r--r--classes/PhpIsisDb.php6
5 files changed, 19 insertions, 19 deletions
diff --git a/classes/IsisConnector.php b/classes/IsisConnector.php
index fe8cd75..c0fd3fc 100644
--- a/classes/IsisConnector.php
+++ b/classes/IsisConnector.php
@@ -12,9 +12,9 @@ class IsisConnector {
$this->isis = new CinisisDb();
if ($this->isis->db) {
- $this->rows = $this->isis->db->rows();
- $this->format = $this->isis->db->format;
- $this->fields = $this->format['fields'];
+ $this->entries = $this->isis->db->entries();
+ $this->format = $this->isis->db->format;
+ $this->fields = $this->format['fields'];
}
else {
return FALSE;
@@ -24,15 +24,15 @@ class IsisConnector {
/**
* Alias to $isis->db->read().
*
- * @param $row
+ * @param $entry
* Row number.
*
* @return
* Resulting data.
*/
- public function read($row) {
+ public function read($entry) {
// Always store the last result.
- $this->result = $this->isis->db->read($row);
+ $this->result = $this->isis->db->read($entry);
// Return the result.
return $this->result;
diff --git a/classes/BiblioIsisDb.php b/classes/BiblioIsisDb.php
index eabf892..22586ed 100644
--- a/classes/BiblioIsisDb.php
+++ b/classes/BiblioIsisDb.php
@@ -127,11 +127,11 @@ class BiblioIsisDb implements IsisDb {
}
/**
* Return number of rows in the database.
*
- * @see IsisDb::read()
+ * @see IsisDb::entries()
*/
- public function rows() {
+ public function entries() {
return $this->backend('count');
}
@@ -127,11 +127,11 @@ class BiblioIsisDb implements IsisDb {
}
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*
diff --git a/classes/IsisDb.php b/classes/IsisDb.php
index 43a51dc..4a2218a 100644
--- a/classes/IsisDb.php
+++ b/classes/IsisDb.php
@@ -24,17 +24,17 @@ interface IsisDb {
* Read an entry from the database.
*
* @param $id
- * Database row id.
+ * Database entry id.
*/
public function read($id);
/**
* Return number of rows in the database.
*
* @return
* Number of rows in the database.
*/
- public function rows();
+ public function entries();
/**
* Return an example database schema.
@@ -24,17 +24,17 @@ interface IsisDb {
public function read($id);
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*
* @return
@@ -24,17 +24,17 @@ interface IsisDb {
*
* @return
- * Number of rows in the database.
+ * Number of entries in the database.
*/
diff --git a/classes/MaleteDb.php b/classes/MaleteDb.php
index e7d50a5..7983c2f 100644
--- a/classes/MaleteDb.php
+++ b/classes/MaleteDb.php
@@ -70,15 +70,15 @@ class MaleteDb implements IsisDb {
}
/**
* Return number of rows in the database.
*
* The Malete API doen't implement such feature so we
* have to emulate it by iterating over all entries
* until MaleteDb::read() returns FALSE.
*
- * @see IsisDb::read()
+ * @see IsisDb::entries()
*/
- public function rows() {
+ public function entries() {
// The first entry in a malete database has id 1 and
// not 0, therefore $id's initial value should be 1.
$id = 1;
@@ -70,15 +70,15 @@ class MaleteDb implements IsisDb {
}
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*
* The Malete API doen't implement such feature so we
diff --git a/classes/PhpIsisDb.php b/classes/PhpIsisDb.php
index 03e9b7c..aa1c239 100644
--- a/classes/PhpIsisDb.php
+++ b/classes/PhpIsisDb.php
@@ -69,11 +69,11 @@ class PhpIsisDb implements IsisDb {
}
/**
* Return number of rows in the database.
*
- * @see IsisDb::rows()
+ * @see IsisDb::entries()
*/
- public function rows() {
+ public function entries() {
return isis_last_mfn($this->db);
}
@@ -69,11 +69,11 @@ class PhpIsisDb implements IsisDb {
}
/**
- * Return number of rows in the database.
+ * Return number of entries in the database.
*